::: spotify.api.API
    options:
      members:
        - get_playback_state
        - transfer_playback
        - get_available_devices
        - get_currently_playing_track
        - start_or_resume_playback
        - pause_playback
        - skip_to_next
        - skip_to_previous
        - seek_to_position
        - set_repeat_mode
        - set_playback_volume
        - set_playback_shuffle
        - get_recently_played_tracks
        - get_users_queue
        - add_item_to_playback_queue
::: spotify.models.Player
::: spotify.models.PlayerTrack
::: spotify.models.Device
::: spotify.models.PlayHistory
::: spotify.models.Queue
::: spotify.models.Context
::: spotify.models.Actions
